pub enum DataflowError {
DecodeError(Box<DecodeError>),
EvalError(Box<EvalError>),
SourceError(Box<SourceError>),
EnvelopeError(Box<EnvelopeError>),
}Expand description
An error that’s destined to be presented to the user in a differential dataflow collection. For example, a divide by zero will be visible in the error collection for a particular row.
All of the variants are boxed to minimize the memory size of DataflowError. This type is
likely to appear in Result<Row, DataflowError>s on high-throughput code paths, so keeping its
size less than or equal to that of Row is important to ensure we are not wasting memory.
Variants
DecodeError(Box<DecodeError>)
EvalError(Box<EvalError>)
SourceError(Box<SourceError>)
EnvelopeError(Box<EnvelopeError>)